@@ -24,10 +24,9 @@ if TYPE_CHECKING:
     from move import Move
     from client import Client
     from player import PlayingPlayer
-    from qt import QPushButton
     from deferredutil import Request
     from user import User
-    from humanclient import HumanClient
+    from humanclient import HumanClient, DlgButton
     from scene import PlayingScene
 
 
@@ -183,7 +182,7 @@ class ClientMessage(Message):
             self.shortcut)
         return self.i18nName.replace(i18nShortcut, '&' + i18nShortcut, 1)
 
-    def toolTip(self, button:'QPushButton', tile:Optional[Tile]) ->Tuple[str, bool, str]: # pylint: disable=unused-argument
+    def toolTip(self, button:'DlgButton', tile:Tile) ->Tuple[str, bool, str]: # pylint: disable=unused-argument
         """return text and warning flag for button and text for tile for button and text for tile"""
         txt = f'toolTip is not defined for {self.name}'
         logWarning(txt)
@@ -248,11 +247,13 @@ class PungChowMessage(NotifyAtOnceMessage):
     def __init__(self, name:Optional[str]=None, shortcut:Optional[str]=None) ->None:
         NotifyAtOnceMessage.__init__(self, name=name, shortcut=shortcut)
 
-    def toolTip(self, button:'QPushButton', tile:Optional[Tile]) ->Tuple[str, bool, str]:
+    def toolTip(self, button:'DlgButton', tile:Tile) ->Tuple[str, bool, str]:
         """for the action button which will send this message"""
-        myself = button.client.game.myself
+        if not button.client.game:
+            return '', False, ''
+        myself = cast('PlayingPlayer', button.client.game.myself)
         maySay = myself.sayable[self]
-        if not maySay:
+        if not maySay or not myself.game:
             return '', False, ''
         txt = []
         warn = False
@@ -264,18 +265,20 @@ class PungChowMessage(NotifyAtOnceMessage):
         if dangerousMelds:
             lastDiscard = myself.game.lastDiscard
             warn = True
-            if Debug.dangerousGame and len(dangerousMelds) != len(maySay):
-                button.client.game.debug(
-                    f'only some claimable melds are dangerous: {dangerousMelds}')
-            if len(dangerousMelds) == 1:
-                txt.append(i18n(
-                    'claiming %1 is dangerous because you will have to discard a dangerous tile',
-                    lastDiscard.name()))
-            else:
-                for meld in dangerousMelds:
+            if Debug.dangerousGame:
+                if not isinstance(maySay, bool) and len(dangerousMelds) != len(maySay):
+                    button.client.game.debug(
+                        f'only some claimable melds are dangerous: {dangerousMelds}')
+            if lastDiscard:
+                if len(dangerousMelds) == 1:
                     txt.append(i18n(
-                        'claiming %1 for %2 is dangerous because you will have to discard a dangerous tile',
-                        lastDiscard.name(), str(meld)))
+                        'claiming %1 is dangerous because you will have to discard a dangerous tile',
+                        lastDiscard.name()))
+                else:
+                    for meld in dangerousMelds:
+                        txt.append(i18n(
+                            'claiming %1 for %2 is dangerous because you will have to discard a dangerous tile',
+                            lastDiscard.name(), str(meld)))
         if not txt:
             txt = [i18n('You may say %1', self.i18nName)]
         return '<br><br>'.join(txt), warn, ''
@@ -320,9 +323,11 @@ class MessageKong(NotifyAtOnceMessage, ServerMessage):
         else:
             table.declareKong(msg.player, Meld(msg.args[0]))
 
-    def toolTip(self, button:'QPushButton', tile:Optional[Tile]) ->Tuple[str, bool, str]:
+    def toolTip(self, button:'DlgButton', tile:Tile) ->Tuple[str, bool, str]:
         """for the action button which will send this message"""
-        myself = button.client.game.myself
+        if not button.client.game:
+            return '', False, ''
+        myself = cast('PlayingPlayer', button.client.game.myself)
         maySay = myself.sayable[self]
         if not maySay:
             return '', False, ''
@@ -330,10 +335,12 @@ class MessageKong(NotifyAtOnceMessage, ServerMessage):
         warn = False
         if myself.originalCall and myself.mayWin:
             warn = True
+            assert isinstance(maySay, MeldList)
             txt.append(
                 i18n('saying Kong for %1 violates Original Call',
                      Tile(maySay[0][0]).name()))
         if not txt:
+            assert isinstance(maySay, MeldList)
             txt = [i18n('You may say Kong for %1', Tile(maySay[0][0]).name())]
         return '<br><br>'.join(txt), warn, ''
 
@@ -391,7 +398,7 @@ class MessageMahJongg(NotifyAtOnceMessage, ServerMessage):
         """the server mirrors that and tells all others"""
         table.claimMahJongg(msg)
 
-    def toolTip(self, button:'QPushButton', tile:Optional[Tile]) ->Tuple[str, bool, str]:
+    def toolTip(self, button:'DlgButton', tile:Tile) ->Tuple[str, bool, str]:
         """return text and warning flag for button and text for tile"""
         return i18n('Press here and you win'), False, ''
 
@@ -415,9 +422,12 @@ class MessageOriginalCall(NotifyAtOnceMessage, ServerMessage):
         """the server tells all others"""
         table.clientDiscarded(msg)
 
-    def toolTip(self, button:'QPushButton', tile:Optional[Tile]) ->Tuple[str, bool, str]:
+    def toolTip(self, button:'DlgButton', tile:Tile) ->Tuple[str, bool, str]:
         """for the action button which will send this message"""
+        # TODO: factor out common assertions
         assert isinstance(tile, Tile), tile
+        if not button.client.game:
+            return '', False, ''
         myself = button.client.game.myself
         isCalling = bool((myself.hand - tile).callingHands)
         if not isCalling:
@@ -459,11 +469,13 @@ class MessageDiscard(ClientMessage, ServerMessage):
         """the server mirrors that action"""
         table.clientDiscarded(msg)
 
-    def toolTip(self, button:'QPushButton', tile:Optional[Tile]) ->Tuple[str, bool, str]:
+    def toolTip(self, button:'DlgButton', tile:Tile) ->Tuple[str, bool, str]:
         """for the action button which will send this message"""
         assert isinstance(tile, Tile), tile
+        if not button.client.game:
+            return '', False, ''
         game = button.client.game
-        myself = game.myself
+        myself = cast('PlayingPlayer', game.myself)
         txt = []
         warn = False
         if myself.violatesOriginalCall(tile):
@@ -903,7 +915,7 @@ class MessageOK(ClientMessage):
                                name=i18ncE('kajongg', 'OK'),
                                shortcut=i18ncE('kajongg game dialog:Key for OK', 'O'))
 
-    def toolTip(self, button:'QPushButton', tile:Optional[Tile]) ->Tuple[str, bool, str]:
+    def toolTip(self, button:'DlgButton', tile:Tile) ->Tuple[str, bool, str]:
         """return text and warning flag for button and text for tile for button and text for tile"""
         return i18n('Confirm that you saw the message'), False, ''
 
@@ -917,7 +929,7 @@ class MessageNoClaim(NotifyAtOnceMessage, ServerMessage):
                                      name=i18ncE('kajongg', 'No Claim'),
                                      shortcut=i18ncE('kajongg game dialog:Key for No claim', 'N'))
 
-    def toolTip(self, button:'QPushButton', tile:Optional[Tile]) ->Tuple[str, bool, str]:
+    def toolTip(self, button:'DlgButton', tile:Tile) ->Tuple[str, bool, str]:
         """return text and warning flag for button and text for tile for button and text for tile"""
         return i18n('You cannot or do not want to claim this tile'), False, ''
 
